Description Usage Arguments Examples
A function to plot biodiversity data in grids.
1 2 3 4 5 6 7 8 9 | gg_bee(input, density = NULL, icon_color = "black",
legend_title = "input", filling = NULL, na = "white", map = NULL,
img = NULL, y_sf = NULL, x_sf = NULL, breaks = NULL,
size = NULL, scal_cont = NULL, break_n = 7,
low = "lightgoldenrod", high = "darkgoldenrod", alpha = 0.7,
map_col = "grey30", panel_background = "grey95", width = 0.25,
breaks_x = NULL, breaks_y = NULL, map_title = NULL,
proj_b = NULL, cellsize = 2, break_hex = NULL, hex_col = "black",
hex_width = 0.5, square = NULL)
|
icon_color |
choose color to change icon |
filling |
choose pallete to color the diferent levels |
na |
color for NA cells |
map |
map to plot on top of input |
img |
forg/lizard/bird/mammal |
y_sf |
y position for icon |
x_sf |
x position for icon |
breaks |
choose breaks for color legend |
size |
size of icon |
scal_cont |
TRUE for gradient scale |
low |
color for gradient scale |
high |
color for gradient scale |
alpha |
icon transparency 0-1 |
map_col |
color for map border |
panel_background |
color for plot background |
width |
width of map |
breaks_x |
choose breaks for x axis |
proj_b |
TRUE if using Berhman projection - default: FALSE |
cellsize |
chose size of grids - default is 2 |
break_hex |
Decide if you want the grid to be cropped by countries borders, default - NULL |
hex_col |
hexagon color defualt -'black' |
hex_width |
hexagon border width, default - 0.5 |
square |
TRUE if square grid, FALSE produces an hexagon grid, default - FALSE |
breaks_n |
number of breaks for color legend |
breaks_y=choose |
breaks for y axis) |
labels |
information to display in the legend |
resolution |
grid resolution |
crs |
projection of data provided ('longlat'/'cea') |
zoom_out |
choose the best zoom to visualize your data |
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.